==> doctorlink-design-system-1.1.0.tgz: package/es/Components/reset.js <==
import styled from 'styled-components';

const htmlStyle = styled.html`
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
  font-family: ${p => p.theme.text.body.fontFamily};
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
  outline: none;
`;
export const html = styled(htmlStyle);
export const body = styled(htmlStyle.withComponent('body').extend`
  line-height: 1;
`);
export const div = styled(htmlStyle.withComponent('div'));
export const span = styled(htmlStyle.withComponent('span'));
export const applet = styled(htmlStyle.withComponent('applet'));
export const object = styled(htmlStyle.withComponent('object'));
export const iframe = styled(htmlStyle.withComponent('iframe'));
export const input = styled(htmlStyle.withComponent('input'));
export const h1 = styled(htmlStyle.withComponent('h1'));
export const h2 = styled(htmlStyle.withComponent('h2'));
export const h3 = styled(htmlStyle.withComponent('h3'));
export const h4 = styled(htmlStyle.withComponent('h4'));
export const h5 = styled(htmlStyle.withComponent('h5'));
export const h6 = styled(htmlStyle.withComponent('h6'));
export const p = styled(htmlStyle.withComponent('p'));
export const pre = styled(htmlStyle.withComponent('pre'));
export const a = styled(htmlStyle.withComponent('a'));
export const abbr = styled(htmlStyle.withComponent('abbr'));
export const acronym = styled(htmlStyle.withComponent('acronym'));
export const address = styled(htmlStyle.withComponent('address'));
export const big = styled(htmlStyle.withComponent('big'));
export const cite = styled(htmlStyle.withComponent('cite'));
export const code = styled(htmlStyle.withComponent('code'));
export const del = styled(htmlStyle.withComponent('del'));
export const dfn = styled(htmlStyle.withComponent('dfn'));
export const em = styled(htmlStyle.withComponent('em'));
export const img = styled(htmlStyle.withComponent('img'));
export const ins = styled(htmlStyle.withComponent('ins'));
export const kbd = styled(htmlStyle.withComponent('kbd'));
export const s = styled(htmlStyle.withComponent('s'));
export const samp = styled(htmlStyle.withComponent('samp'));
export const small = styled(htmlStyle.withComponent('small'));
export const strike = styled(htmlStyle.withComponent('strike'));
export const strong = styled(htmlStyle.withComponent('strong'));
export const sub = styled(htmlStyle.withComponent('sub'));
export const sup = styled(htmlStyle.withComponent('sup'));
export const tt = styled(htmlStyle.withComponent('tt'));
// export const var = styled(htmlStyle.withComponent('var'));
export const b = styled(htmlStyle.withComponent('b'));
export const u = styled(htmlStyle.withComponent('u'));
export const i = styled(htmlStyle.withComponent('i'));
export const center = styled(htmlStyle.withComponent('center'));
export const dl = styled(htmlStyle.withComponent('dl'));
export const dt = styled(htmlStyle.withComponent('dt'));
export const dd = styled(htmlStyle.withComponent('dd'));
export const li = styled(htmlStyle.withComponent('li'));
export const fieldset = styled(htmlStyle.withComponent('fieldset'));
export const form = styled(htmlStyle.withComponent('form'));
export const label = styled(htmlStyle.withComponent('label'));
export const legend = styled(htmlStyle.withComponent('legend'));
export const caption = styled(htmlStyle.withComponent('caption'));
export const tbody = styled(htmlStyle.withComponent('tbody'));
export const tfoot = styled(htmlStyle.withComponent('tfoot'));
export const thead = styled(htmlStyle.withComponent('thead'));
export const tr = styled(htmlStyle.withComponent('tr'));
export const th = styled(htmlStyle.withComponent('th'));
export const td = styled(htmlStyle.withComponent('td'));
export const canvas = styled(htmlStyle.withComponent('canvas'));
export const embed = styled(htmlStyle.withComponent('embed'));
export const output = styled(htmlStyle.withComponent('output'));
export const ruby = styled(htmlStyle.withComponent('ruby'));
export const summary = styled(htmlStyle.withComponent('summary'));
export const time = styled(htmlStyle.withComponent('time'));
export const mark = styled(htmlStyle.withComponent('mark'));
export const audio = styled(htmlStyle.withComponent('audio'));
export const video = styled(htmlStyle.withComponent('video'));

/* HTML5 display-role reset for older browsers */
const articleStyle = htmlStyle.withComponent('article').extend`
  display: block;
`;
export const article = styled(articleStyle);
export const aside = styled(articleStyle.withComponent('aside'));
export const details = styled(articleStyle.withComponent('details'));
export const figcaption = styled(articleStyle.withComponent('figcaption'));
export const figure = styled(articleStyle.withComponent('figure'));
export const footer = styled(articleStyle.withComponent('footer'));
export const header = styled(articleStyle.withComponent('header'));
export const hgroup = styled(articleStyle.withComponent('hgroup'));
export const menu = styled(articleStyle.withComponent('menu'));
export const nav = styled(articleStyle.withComponent('nav'));
export const section = styled(articleStyle.withComponent('section'));

const olStyle = htmlStyle.withComponent('ol').extend`
  list-style: none;
`;
export const ol = styled(olStyle);
export const ul = styled(olStyle.withComponent('ul'));

const blockquoteStyle = htmlStyle.withComponent('blockquote').extend`
  quotes: none;
  &:before, &:after {
    content: '';
    content: none;
  }
`;
export const blockquote = styled(blockquoteStyle);
export const q = styled(blockquoteStyle.withComponent('q'));

export const table = styled(htmlStyle.withComponent('table').extend`
  border-collapse: collapse;
  border-spacing: 0;
`);

export const button = styled.button;

==> doctorlink-design-system-1.1.6.tgz: package/es/Components/reset.js <==
import styled from 'styled-components';

const htmlStyle = styled.html`
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
  font-family: ${p => p.theme.text.fontFamily};
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
  outline: none;
`;
export const html = styled(htmlStyle);
export const body = styled(htmlStyle.withComponent('body').extend`
  line-height: 1;
`);
export const div = styled(htmlStyle.withComponent('div'));
export const span = styled(htmlStyle.withComponent('span'));
export const applet = styled(htmlStyle.withComponent('applet'));
export const object = styled(htmlStyle.withComponent('object'));
export const iframe = styled(htmlStyle.withComponent('iframe'));
export const input = styled(htmlStyle.withComponent('input'));
export const h1 = styled(htmlStyle.withComponent('h1'));
export const h2 = styled(htmlStyle.withComponent('h2'));
export const h3 = styled(htmlStyle.withComponent('h3'));
export const h4 = styled(htmlStyle.withComponent('h4'));
export const h5 = styled(htmlStyle.withComponent('h5'));
export const h6 = styled(htmlStyle.withComponent('h6'));
export const p = styled(htmlStyle.withComponent('p'));
export const pre = styled(htmlStyle.withComponent('pre'));
export const a = styled(htmlStyle.withComponent('a'));
export const abbr = styled(htmlStyle.withComponent('abbr'));
export const acronym = styled(htmlStyle.withComponent('acronym'));
export const address = styled(htmlStyle.withComponent('address'));
export const big = styled(htmlStyle.withComponent('big'));
export const cite = styled(htmlStyle.withComponent('cite'));
export const code = styled(htmlStyle.withComponent('code'));
export const del = styled(htmlStyle.withComponent('del'));
export const dfn = styled(htmlStyle.withComponent('dfn'));
export const em = styled(htmlStyle.withComponent('em'));
export const img = styled(htmlStyle.withComponent('img'));
export const ins = styled(htmlStyle.withComponent('ins'));
export const kbd = styled(htmlStyle.withComponent('kbd'));
export const s = styled(htmlStyle.withComponent('s'));
export const samp = styled(htmlStyle.withComponent('samp'));
export const small = styled(htmlStyle.withComponent('small'));
export const strike = styled(htmlStyle.withComponent('strike'));
export const strong = styled(htmlStyle.withComponent('strong'));
export const sub = styled(htmlStyle.withComponent('sub'));
export const sup = styled(htmlStyle.withComponent('sup'));
export const tt = styled(htmlStyle.withComponent('tt'));
// export const var = styled(htmlStyle.withComponent('var'));
export const b = styled(htmlStyle.withComponent('b'));
export const u = styled(htmlStyle.withComponent('u'));
export const i = styled(htmlStyle.withComponent('i'));
export const center = styled(htmlStyle.withComponent('center'));
export const dl = styled(htmlStyle.withComponent('dl'));
export const dt = styled(htmlStyle.withComponent('dt'));
export const dd = styled(htmlStyle.withComponent('dd'));
export const li = styled(htmlStyle.withComponent('li'));
export const fieldset = styled(htmlStyle.withComponent('fieldset'));
export const form = styled(htmlStyle.withComponent('form'));
export const label = styled(htmlStyle.withComponent('label'));
export const legend = styled(htmlStyle.withComponent('legend'));
export const caption = styled(htmlStyle.withComponent('caption'));
export const tbody = styled(htmlStyle.withComponent('tbody'));
export const tfoot = styled(htmlStyle.withComponent('tfoot'));
export const thead = styled(htmlStyle.withComponent('thead'));
export const tr = styled(htmlStyle.withComponent('tr'));
export const th = styled(htmlStyle.withComponent('th'));
export const td = styled(htmlStyle.withComponent('td'));
export const canvas = styled(htmlStyle.withComponent('canvas'));
export const embed = styled(htmlStyle.withComponent('embed'));
export const output = styled(htmlStyle.withComponent('output'));
export const ruby = styled(htmlStyle.withComponent('ruby'));
export const summary = styled(htmlStyle.withComponent('summary'));
export const time = styled(htmlStyle.withComponent('time'));
export const mark = styled(htmlStyle.withComponent('mark'));
export const audio = styled(htmlStyle.withComponent('audio'));
export const video = styled(htmlStyle.withComponent('video'));

/* HTML5 display-role reset for older browsers */
const articleStyle = htmlStyle.withComponent('article').extend`
  display: block;
`;
export const article = styled(articleStyle);
export const aside = styled(articleStyle.withComponent('aside'));
export const details = styled(articleStyle.withComponent('details'));
export const figcaption = styled(articleStyle.withComponent('figcaption'));
export const figure = styled(articleStyle.withComponent('figure'));
export const footer = styled(articleStyle.withComponent('footer'));
export const header = styled(articleStyle.withComponent('header'));
export const hgroup = styled(articleStyle.withComponent('hgroup'));
export const menu = styled(articleStyle.withComponent('menu'));
export const nav = styled(articleStyle.withComponent('nav'));
export const section = styled(articleStyle.withComponent('section'));

const olStyle = htmlStyle.withComponent('ol').extend`
  list-style: none;
`;
export const ol = styled(olStyle);
export const ul = styled(olStyle.withComponent('ul'));

const blockquoteStyle = htmlStyle.withComponent('blockquote').extend`
  quotes: none;
  &:before, &:after {
    content: '';
    content: none;
  }
`;
export const blockquote = styled(blockquoteStyle);
export const q = styled(blockquoteStyle.withComponent('q'));

export const table = styled(htmlStyle.withComponent('table').extend`
  border-collapse: collapse;
  border-spacing: 0;
`);

export const button = styled.button;
